@@ -206,7 +206,7 @@ class Query(object):
             logging.info(
                  '%.2f\n\t%s ;'%(
                     1000*(time() - begin_time),
-                    sql.strip()%tuple(map(escape_string,values))
+                    sql.strip()%tuple(map(escape_string,map(str, values)))
                 )
             )
         return cursor
